@@ -1,5 +1,6 @@
 import logging
 
+import markdown
 import django_filters
 from django.conf import settings
 from django.db.models import QuerySet
@@ -12,6 +13,7 @@ from rest_framework.permissions import IsAuthenticated
 from rest_framework.request import Request
 from rest_framework.response import Response
 from rest_framework.reverse import reverse
+from rest_framework.decorators import action
 
 from .enums import WidgetType
 from .filters import BooleanFilter, ModelChoiceFilter
@@ -97,6 +99,27 @@ class ModelViewSet(
     def get_serializer(self, *args, **kwargs):
         return self.get_serializer_changes(super().get_serializer(*args, **kwargs))
 
+    @action(methods=["get"], detail=False, url_name="list-docs")
+    def __list_docs__(self, request, *args, **kwargs):
+        try:
+            with open(self.LIST_DOCS, "r") as f:
+                return Response(f.read())
+        except FileNotFoundError:
+            return Response(self.LIST_DOCS)
+        except AttributeError:
+            return Response("No documentation available.")
+        
+
+    @action(methods=["get"], detail=True, url_name="instance-docs")
+    def __instance_docs__(self, request, *args, **kwargs):
+        try:
+            with open(self.INSTANCE_DOCS, "r") as f:
+                return Response(f.read())
+        except FileNotFoundError:
+            return Response(self.INSTANCE_DOCS)
+        except AttributeError:
+            return Response("No documentation available.")
+
 
 class InfiniteDataModelView(ModelViewSet):
 
